# FlowPeaks Clustering

This module uses the flowPeaks algorithm to assign events to clusters in an unsupervized manner.

Name

  The operation name; determines the name of the new metadata

X Channel, Y Channel

  The channels to apply the mixture model to.

X Scale, Y Scale

  Re-scale the data in Channel before fitting.

h, h0

  Scalar values that control the smoothness of the estimated distribution. Increasing h makes it “rougher,” while increasing h0 makes it smoother.

tol

  How readily should clusters be merged? Must be between 0 and 1.

Merge Distance

  How far apart can clusters be before they are merged?

By

  A list of metadata attributes to aggregate the data before estimating the model. For example, if the experiment has two pieces of metadata, `Time` and `Dox`, setting By to `["Time", "Dox"]` will fit the model separately to each subset of the data with a unique combination of `Time` and `Dox`.